==> ejc-proother-impl-3.0.0-20220329.124042-20-sources.jar: com/ejianc/business/proother/bean/ChangeClauseEntity.java <==
package com.ejianc.business.proother.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 分包变更条款实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proother_contract_change_clause")
public class ChangeClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    @TableField("clause_name_id")
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    @TableField("clause_name")
    private String clauseName;

    /**
     * 合同条款内容
     */
    @TableField("clause_content")
    private String clauseContent;


    /**
     * 变更主键
     */
    @TableField("change_id")
    private Long changeId;


    /**
     * 来源子表主键
     */
    @TableField("src_tbl_id")
    private Long srcTblId;

    /**
     * 合同ID
     */
    @TableField("contract_id")
    private Long contractId;

    /**
     * 对比清单使用字段——原条款内容
     */
    @TableField("before_clause_content")
    private String beforeClauseContent;



    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }


    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }


    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public String getBeforeClauseContent() {
        return beforeClauseContent;
    }

    public void setBeforeClauseContent(String beforeClauseContent) {
        this.beforeClauseContent = beforeClauseContent;
    }
}

==> ejc-proother-impl-3.0.0-20220519.093023-58-sources.jar: com/ejianc/business/proother/bean/ChangeClauseEntity.java <==
package com.ejianc.business.proother.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 分包变更条款实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proother_contract_change_clause")
public class ChangeClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    @TableField("clause_name_id")
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    @TableField("clause_name")
    private String clauseName;

    /**
     * 合同条款内容
     */
    @TableField("clause_content")
    private String clauseContent;

    /**
     * 是否必填：1-是，0否
     */
    @TableField("necessary_status")
    private Integer necessaryStatus;


    /**
     * 变更主键
     */
    @TableField("change_id")
    private Long changeId;


    /**
     * 来源子表主键
     */
    @TableField("src_tbl_id")
    private Long srcTblId;

    /**
     * 合同ID
     */
    @TableField("contract_id")
    private Long contractId;

    /**
     * 对比清单使用字段——原条款内容
     */
    @TableField("before_clause_content")
    private String beforeClauseContent;



    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }


    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }


    public Long getSrcTblId() {
        return srcTblId;
    }

    public void setSrcTblId(Long srcTblId) {
        this.srcTblId = srcTblId;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }

    public String getBeforeClauseContent() {
        return beforeClauseContent;
    }

    public void setBeforeClauseContent(String beforeClauseContent) {
        this.beforeClauseContent = beforeClauseContent;
    }
}
